"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.shuffleArray = exports.useScroll = exports.useHeight = exports.useWidth = exports.useDebounce = void 0;
const react_1 = require("react");
const useDebounce = (value, delay) => {
    const [debouncedValue, setDebouncedValue] = (0, react_1.useState)(value);
    (0, react_1.useEffect)(() => {
        const handler = setTimeout(() => {
            setDebouncedValue(value);
        }, delay);
        return () => {
            clearTimeout(handler);
        };
    }, [value, delay]);
    return debouncedValue;
};
exports.useDebounce = useDebounce;
const useWidth = () => {
    const [width, setWidth] = (0, react_1.useState)(0);
    const handleResize = () => setWidth(window.innerWidth);
    (0, react_1.useEffect)(() => {
        setWidth(window.innerWidth);
        window.addEventListener("resize", handleResize);
        return () => window.removeEventListener("resize", handleResize);
    }, []);
    return width;
};
exports.useWidth = useWidth;
const useHeight = () => {
    const [height, setHeight] = (0, react_1.useState)(0);
    const handleResize = () => setHeight(window.innerHeight);
    (0, react_1.useEffect)(() => {
        setHeight(window.innerHeight);
        window.addEventListener("resize", handleResize);
        return () => window.removeEventListener("resize", handleResize);
    }, []);
    return height;
};
exports.useHeight = useHeight;
const useScroll = () => {
    const [scroll, setScroll] = (0, react_1.useState)(0);
    const handleScroll = () => setScroll(window.pageYOffset);
    (0, react_1.useEffect)(() => {
        setScroll(window.pageYOffset);
        window.removeEventListener("scroll", handleScroll);
        window.addEventListener("scroll", handleScroll, { passive: true });
        return () => window.removeEventListener("scroll", handleScroll);
    }, []);
    return scroll;
};
exports.useScroll = useScroll;
const shuffleArray = (array) => {
    for (let i = array.length - 1; i > 0; i--) {
        const j = Math.floor(Math.random() * (i + 1));
        const temp = array[i];
        array[i] = array[j];
        array[j] = temp;
    }
    return array;
};
exports.shuffleArray = shuffleArray;
